@@ -128,22 +128,24 @@ class TestCommon(TestCase):
         self.assertIsNotNone(list(codext.generate_strings_from_regex(r"[^a]")))
     
     def test_guess_decode(self):
+        _l = lambda d: list(d.items())[0][1]
         codext.reset()
         STR = "This is a test"
-        self.assertEqual(STR, codext.guess("VGhpcyBpcyBhIHRlc3Q=", "a test", 1)[0][0])
-        self.assertEqual(STR, codext.guess("CJG3Ix8bVcSRMLOqwDUg28aDsT7", "a test", found=["base62"])[0][0])
+        self.assertEqual(STR, _l(codext.guess("VGhpcyBpcyBhIHRlc3Q=", "a test", 1)))
+        self.assertEqual(STR, _l(codext.guess("CJG3Ix8bVcSRMLOqwDUg28aDsT7", "a test", found=["base62"])))
         if hasattr(codext.stopfunc, "lang_en"):
             f = codext.stopfunc.lang_en
-            self.assertEqual(STR, codext.guess("CJG3Ix8bVcSRMLOqwDUg28aDsT7", f, found=["base62"])[0][0])
-            self.assertIsNotNone(codext.guess("CJG3Ix8bVcSRMLOqwDUg28aDsT7", f, max_depth=1)[0][0])
-        self.assertEqual(STR, codext.guess("VGhpcyBpcyBhIHRlc3Q=", "a test", 1, "base", exclude=["base100"])[0][0])
-        self.assertEqual(STR, codext.guess("VGhpcyBpcyBhIHRlc3Q=", "a test", 1, ["base", "crypto"])[0][0])
+            self.assertEqual(STR, _l(codext.guess("CJG3Ix8bVcSRMLOqwDUg28aDsT7", f, found=["base62"])))
+            self.assertIsNotNone(_l(codext.guess("CJG3Ix8bVcSRMLOqwDUg28aDsT7", f, max_depth=1)))
+        self.assertEqual(STR, _l(codext.guess("VGhpcyBpcyBhIHRlc3Q=", "a test", 1, "base", scoring_heuristic=True,
+                                              exclude=["base100"])))
+        self.assertEqual(STR, _l(codext.guess("VGhpcyBpcyBhIHRlc3Q=", "a test", 1, ["base", "crypto"])))
         self.assertEqual(len(codext.guess("NOT THE ENCODED TEST STRING", "a test", 1, exclude=[None])), 0)
-        self.assertIn("F1@9", codext.guess("VGVzdCBGMUA5ICE=", codext.stopfunc.flag, 1, stop=False, show=True)[0][0])
+        self.assertIn("F1@9", _l(codext.guess("VGVzdCBGMUA5ICE=", codext.stopfunc.flag, 1, stop=False, show=True)))
         self.assertEqual(len(codext.guess("VGhpcyBpcyBhIHRlc3Q=", " a test", 1, codec_categories="base",
                                           exclude="base64")), 0)
         self.assertEqual(len(codext.guess("VGhpcyBpcyBhIHRlc3Q=", " a test", 1, codec_categories="base",
-                                          exclude=("base64", "atbash"))), 0)
+                                          scoring_heuristic=True, exclude=("base64", "atbash"))), 0)
         self.assertRaises(ValueError, codext.guess, STR, max_depth=0)
         self.assertRaises(ValueError, codext.guess, STR, exclude=42)
         for c in ["base", "language", "native", "stegano"]:
@@ -159,7 +161,8 @@ class TestCommon(TestCase):
                         enc = codext.encode(b(STR), encoding)
                     if codext.decode(enc, encoding) == STR:
                         continue
-                    for found_dec, found_encodings in codext.guess(enc, "a test", 1, [c]):
+                    for found_encodings, found_dec in codext.guess(enc, "a test", 1, [c], scoring_heuristic=True,
+                                                                   debug=True).items():
                         self.assertEqual(ensure_str(STR).lower(), ensure_str(found_dec).lower())
                         if c != "base":
                             # do not check for base as the guessed encoding name can be different, e.g.:
@@ -171,5 +174,6 @@ class TestCommon(TestCase):
                                 self.assertEqual(encoding, found_encodings[0])
         txt = "".join(chr(i) for i in range(256))
         b64 = codext.encode(txt, "base64")
-        self.assertEqual(txt, codext.guess(b64, "0123456789", max_depth=1, codec_categories="base")[0][0])
+        self.assertEqual(txt, _l(codext.guess(b64, "0123456789", max_depth=1, scoring_heuristic=True,
+                                              codec_categories="base")))
 
